@@ -11,13 +11,17 @@ use warnings;
 use base qw( Tickit::Widget );
 Tickit::Window->VERSION( '0.42' );
 
-our $VERSION = '0.017';
+our $VERSION = '0.018';
 
 use Scalar::Util qw( weaken );
 use Tickit::Utils qw( textwidth );
 
 use Carp;
 
+# It isn't really; we only use the direct style setting directly from the
+# containing Tickit::Widget::Tabbed
+use constant WIDGET_PEN_FROM_STYLE => 1;
+
 =head1 NAME
 
 C<Tickit::Widget::Tabbed::Ribbon> - base class for C<Tickit::Widget::Tabbed>
